@@ -5,16 +5,15 @@ use warnings;
 
 package Validation::Class::Plugin::FormFields;
 {
-  $Validation::Class::Plugin::FormFields::VERSION = '0.0.1';
+  $Validation::Class::Plugin::FormFields::VERSION = '0.0.5';
 }
 
 use Moose::Role;
-use File::Copy;
 use File::ShareDir qw/dist_dir/;
 use Template;
 use Template::Stash;
 
-our $VERSION = '0.0.1'; # VERSION
+our $VERSION = '0.0.5'; # VERSION
 
 
 # field element templates
@@ -23,7 +22,6 @@ has field_templates => (
     isa     => 'HashRef',
     lazy    => 1,
     default => sub {{
-        dir          => shift->field_templates_location,
         text         => 'text_field.tt',
         password     => 'password_field.tt',
         select       => 'select_field.tt',
@@ -48,7 +46,7 @@ has field_templates_location => (
            $package =~ s/::/\-/g;
            
         eval { $dir = dist_dir($package) };
-        return join "/", $dir, "templates";
+        return $dir ? join "/", $dir, "templates" : "./templates";
     }
 );
 
@@ -56,7 +54,7 @@ has field_templates_location => (
 sub field_template {
     my ($self, $type) = @_;
     return join "/",
-        $self->field_templates->{dir},
+        $self->field_templates_location,
         $self->field_templates->{$type},
 }
 
@@ -105,6 +103,7 @@ $Template::Stash::LIST_OPS->{ in_array } = sub {
     return (grep { $_ eq $query } @$list) ? 1 : 0;
 };
 
+
 1;
 __END__
 =pod
@@ -115,7 +114,7 @@ Validation::Class::Plugin::FormFields - Validation::Class HTML Form Field Render
 
 =head1 VERSION
 
-version 0.0.1
+version 0.0.5
 
 =head1 SYNOPSIS
 
@@ -159,12 +158,26 @@ version 0.0.1
 =head1 DESCRIPTION
 
 More importanly than explaining what this plugin is, I will first proclaim what
-it IS NOT. Validation::Class::Plugin::FormFields is not a HTML form and/or
+it IS NOT. Validation::Class::Plugin::FormFields is not an HTML form and/or
 HTML element construction kit, nor is it a one-size-fits-all form handling machine,
 it is however a plugin for use with your L<Validation::Class> class that allows
 you to render HTML form fields based on your defined validation fields in
 their given states.
 
+So why why render fields individually and not the entire form (fields collection).
+Form generation is pretty evil IMO, whereas the generating of HTML elements is
+less evil and definately alot more rational. Full-blown form generation locks
+you in a box offering only slight convenience and major headaches when you need
+anything more than the out-of-the-box generated output.
+
+Render elements indivually, obviously we have to generate some output or this
+plugin would be a ridiculous waste of space, however .. the generated HTML is
+sensible and consistent to allow easy CSS styling and JavaScript manipulations.
+
+Ever tried to add an HTML5 <button>Click Me</button> or Horizontal Rule <hr/> to
+your form that was generated by that form rendering package you used to use ...?
+Don't render forms with code, Take back control of your controls.
+
 For more information about defining fields (validation rules), feel free to look
 over L<Validation::Class>. 
 
@@ -353,6 +366,20 @@ multi-line text input.
     # renders a single textarea
     my $textarea = $form->render_field($field, 'textarea');
 
+=head1 HTML FORM FIELD TEMPLATES
+
+The HTML form field elements are rendered via TT template (template-toolkit).
+The actual template files are embedded in this distribution however you may copy
+them to your current working directory by issuing the following command at the
+command-line:
+
+    $ Validation-Class-Plugin-FormField-Templates [<path>]
+
+Once copied and modified to your liking, specify the CWD in your validation
+class instance as follows:
+
+    $form->field_templates_location($location);
+
 =head1 AUTHOR
 
 Al Newkirk <awncorp@cpan.org>
